API docs for “spamfighter.rules.test.test_model.ModelRuleTestCase”

# Class s.r.t.t.ModelRuleTestCase(unittest.TestCase):

Part of spamfighter.rules.test.test_model View Source View In Hierarchy

Тест на `spamfighter.rules.model`.

Method | setUp | Undocumented
Method | tearDown | Undocumented
Method | testNoModel | Undocumented
Method | testNotAModel | Undocumented
Method | testNoAttribute | Undocumented
Method | testClassify1 | Undocumented
Method | testClassify2 | Undocumented
Method | testTrain | Undocumented

def setUp(self): (source)
Undocumented
def tearDown(self): (source)
Undocumented
def testNoModel(self): (source)
Undocumented
def testNotAModel(self): (source)
Undocumented
def testNoAttribute(self): (source)
Undocumented
def testClassify1(self): (source)
Undocumented
def testClassify2(self): (source)
Undocumented
def testTrain(self): (source)
Undocumented